import classnames from 'classnames';
import classes from './styles.module.scss';

const Footer = (props) => {
  const { classes: additionalClasses } = props;
  const {
    root: rootClass,
    linksContainer: linksContainerClass,
    link: linkClass,
    legal: legalClass,
  } = additionalClasses;

  return (
    <footer className={classnames(classes.footer, rootClass)}>
      <nav
        className={classnames(
          classes['links-container'],
          'footer__group',
          'footer__group--links',
          linksContainerClass,
        )}
        role="contentinfo"
      >
        <ul>
          <li className={classes.item}>
            <a
              href="https://www.politico.com/about-us"
              className={classnames(
                classes.link, linkClass,
              )}
            >
              About Us

            </a>
          </li>
          <li className={classes.item}>
            <a
              href="https://www.politico.com/advertising"
              className={classnames(
                classes.link, linkClass,
              )}
            >
              Advertising

            </a>
          </li>
          <li className={classes.item}>
            <a
              href="https://www.politico.com/subscribe/breaking-news-alerts"
              className={classnames(
                classes.link, linkClass,
              )}
              target="_top"
            >
              Breaking News Alerts
            </a>
          </li>
          <li className={classes.item}>
            <a
              href="https://www.politico.com/careers"
              className={classnames(
                classes.link, linkClass,
              )}
              target="_blank"
              rel="noreferrer"
            >
              Careers

            </a>
          </li>
          <li className={classes.item}>
            <a
              href="https://www.politico.com/payment"
              className={classnames(
                classes.link, linkClass,
              )}
              target="_top"
            >
              Credit Card Payments

            </a>
          </li>
          <li className={classes.item}>
            <a
              href="http://edition.pagesuite-professional.co.uk/Launch.aspx?bypass=true&amp;PBID=74262970-aa07-44b3-80c8-21fa8a8ac376"
              className={classnames(
                classes.link, linkClass,
              )}
              target="_blank"
              rel="noreferrer"
            >
              Digital Edition
            </a>
          </li>
          <li className={classes.item}>
            <a
              href="https://www.politico.com/faq"
              className={classnames(
                classes.link, linkClass,
              )}
            >
              FAQ
            </a>
          </li>
          <li className={classes.item}>
            <a
              href="https://www.politico.com/feedback"
              className={classnames(
                classes.link, linkClass,
              )}
            >
              Feedback

            </a>
          </li>
          <li className={classes.item}>
            <a
              href="https://www.politico.com/politics"
              className={classnames(
                classes.link, linkClass,
              )}
            >
              Headlines

            </a>
          </li>
          <li className={classes.item}>
            <a
              href="https://www.politico.com/gallery"
              className={classnames(
                classes.link, linkClass,
              )}
            >
              Photos
            </a>
          </li>
          <li className={classes.item}>
            <a
              href="http://www.powerjobs.com/"
              className={classnames(
                classes.link, linkClass,
              )}
              target="_blank"
              rel="noreferrer"
            >
              POWERJobs

            </a>
          </li>
          <li className={classes.item}>
            <a
              href="https://www.politico.com/press/about"
              className={classnames(
                classes.link, linkClass,
              )}
            >
              Press
            </a>
          </li>
          <li className={classes.item}>
            <a
              href="https://www.politico.com/subscriptions"
              className={classnames(
                classes.link, linkClass,
              )}
            >
              Print Subscriptions
            </a>
          </li>
          <li className={classes.item}>
            <a
              href="https://www.politico.com/corrections"
              className={classnames(
                classes.link, linkClass,
              )}
            >
              Request A Correction
            </a>
          </li>
          <li className={classes.item}>
            <a
              href="https://www.politico.com/write-for-us"
              className={classnames(
                classes.link, linkClass,
              )}
              target="_blank"
              rel="noreferrer"
            >
              Write For Us
            </a>
          </li>
          <li className={classes.item}>
            <a
              href="https://www.politico.com/rss"
              className={classnames(
                classes.link, linkClass,
              )}
            >
              RSS

            </a>
          </li>
          <li className={classes.item}>
            <a
              href="https://www.politico.com/sitemap"
              className={classnames(
                classes.link, linkClass,
              )}
            >
              Site Map

            </a>
          </li>
        </ul>
        <ul>
          <li className={classes.item}>
            <a
              href="https://www.politico.com/terms-of-service"
              className={classnames(
                classes.link, linkClass,
              )}
            >
              Terms of Service

            </a>
          </li>
          <li className={classes.item}>
            <a
              href="https://www.politico.com/privacy-policy"
              className={classnames(
                classes.link, linkClass,
              )}
            >
              Privacy Policy
            </a>
          </li>
          <li className={classes.item}>
            <a
              href="https://www.politico.com/do-not-sell"
              className={classnames(
                classes.link, linkClass,
              )}
              target="_blank"
              rel="noreferrer"
            >
              Do not sell my info
            </a>
          </li>
          <li className={classes.item}>
            <a
              href="https://www.politico.com/privacy#california"
              className={classnames(
                classes.link, linkClass,
              )}
              target="_blank"
              rel="noreferrer"
            >
              Notice to California Residents
            </a>
          </li>
        </ul>
      </nav>
      <div className={classnames(
        'footer__group',
        'footer__group--legal',
        classes['footer__group--legal'],
        legalClass,
      )}
      >
        <p className="footer__copyright"> © 2022 POLITICO LLC</p>
      </div>
    </footer>
  );
};

Footer.defaultProps = {
  classes: {},
};

export default Footer;
